@@ -1,6 +1,6 @@
 #! /usr/bin/env tclsh
 
-set teapotservers [list teapot.activestate.com teapot.rkeene.org]
+set teapotservers [list teapot.rkeene.org teapot.activestate.com]
 
 lappend auto_path [file join [file dirname [info script]] lib]
 
