@@ -6,15 +6,20 @@ if [ ! -x "../platform" ]; then
 	exit 1
 fi
 
+if [ "${PLATFORM}" = "tcl" ]; then
+	rm -rf out
+
+	exit 0
+fi
+
 VERS=8.4
 SRC="src/tclx${VERS}.tar.bz2"
 SRCURL="http://sourceforge.net/projects/tclx/files/TclX/${VERS}.0/tclx${VERS}.tar.bz2/download"
 BUILDDIR="tclx${VERS}"
 WORKDIR="${TMPDIR:-/tmp}/tclx-$$${RANDOM}${RANDOM}${RANDOM}"
-PLATFORM="$(../platform)"
 PLATDIR="$(pwd)/out/${PLATFORM}"
 
-export VERS SRC SRCURL BUILDDIR WORKDIR PLATFORM PLATDIR
+export VERS SRC SRCURL BUILDDIR WORKDIR PLATDIR
 
 (
 	rm -rf build
@@ -81,7 +86,7 @@ __EOF__
 __EOF__
 
 
-	bash ./configure --enable-shared --with-tcl="${TCLCONFIGDIR}" --libdir="${PLATDIR}"
+	bash ./configure --enable-shared --with-tcl="${TCLCONFIGDIR}" --libdir="${PLATDIR}" ${CONFIGUREEXTRA}
 	${MAKE:-make} || exit 1
 
 	mkdir -p "${PLATDIR}" >/dev/null 2>/dev/null
