@@ -9,16 +9,22 @@ fi
 CLEANONLY=0
 DISTCLEAN=0
 if [ "$1" = "clean" ]; then
+	shift
 	CLEANONLY=1
 fi
 if [ "$1" = "distclean" ]; then
+	shift
 	CLEANONLY=1
 	DISTCLEAN=1
 fi
 export CLEANONLY DISTCLEAN
 
+CONFIGUREEXTRA="$@"
+export CONFIGUREEXTRA
+
 # Determine path to "tclConfig.sh"
 rm -rf tcl/build
+rm -f platform.magic.*
 if [ "${DISTCLEAN}" = "1" ]; then
 	rm -rf tcl
 fi
@@ -26,6 +32,8 @@ fi
 if [ "${CLEANONLY}" = "0" ]; then
 	TCLVERS="8.4.19"
 	TCLPRIVATE="$(pwd)/tcl/build/tcl${TCLVERS}"
+	PROJROOTDIR="$(pwd)"
+	export TCLVERS TCLPRIVATE PROJROOTDIR
 
 	mkdir tcl tcl/build >/dev/null 2>/dev/null
 
@@ -40,15 +48,39 @@ if [ "${CLEANONLY}" = "0" ]; then
 		cd tcl/build || exit 1
 		gzip -dc "../src/tcl${TCLVERS}.tar.gz" | tar -xf -
 
-		cd "${TCLPRIVATE}/unix" || exit 1
+		for dir in unix win macosx; do
+			cd "${TCLPRIVATE}/${dir}" || exit 1
 
-		./configure --enable-shared
+			echo " Executing: ./configure ${CONFIGUREEXTRA}"
+			./configure --disable-threads ${CONFIGUREEXTRA}
 
-		${MAKE:-make}
-	) > "tcl/build/build.log" 2>&1
+			${MAKE:-make} || continue
 
-	if [ -d "${TCLPRIVATE}" -a -f "${TCLPRIVATE}/unix/tclConfig.sh" ]; then
-		TCLCONFIGDIR="${TCLPRIVATE}/unix"
+			LD_LIBRARY_PATH=".:${LD_LIBRARY_PATH}"
+			LD_RUN_PATH=".:${LD_RUN_PATH}"
+			export LD_LIBRARY_PATH LD_RUN_PATH
+
+			file tclsh tclsh*.exe 2>/dev/null | grep -iv 'No such file' > "${PROJROOTDIR}/platform.magic.file"
+			if [ -f tclsh*.exe ]; then
+				echo 'puts "$::tcl_platform(os)"' | ./tclsh*.exe > "${PROJROOTDIR}/platform.magic.os" 2>/dev/null
+			else
+				echo 'puts "$::tcl_platform(os)"' | ./tclsh > "${PROJROOTDIR}/platform.magic.os" 2>/dev/null
+			fi
+			echo "${dir}" > "${PROJROOTDIR}/platform.magic.platform"
+			pwd > "${PROJROOTDIR}/platform.magic.dir"
+
+			break
+		done
+	) > "tcl/build/build.log" 2>&1 || (
+		echo 'Failed to build Tcl.  See "./tcl/build/build.log"'
+		echo 'Proceeding with system Tcl.  Building might fail.'
+	)
+
+	TCLBUILDDIR="$(cat "${PROJROOTDIR}/platform.magic.dir")"
+	export TCLBUILDDIR
+
+	if [ -d "${TCLBUILDDIR}" -a -f "${TCLBUILDDIR}/tclConfig.sh" ]; then
+		TCLCONFIGDIR="${TCLBUILDDIR}"
 	else
 		unset TCLPRIVATE
 
@@ -68,21 +100,26 @@ if [ "${CLEANONLY}" = "0" ]; then
 			TCLCONFIGDIR="/usr/lib"
 		fi
 
-		TCLPRIVATE="${TCLCONFIGDIR}/../include/tcl-private"
+		TCLPRIVATE="$(dirname "${TCLCONFIGDIR}")/include/tcl-private"
 	fi
 
-	ADDFLAGS="-I${TCLPRIVATE} -I${TCLPRIVATE}/generic -I${TCLPRIVATE}/unix"
+	ADDFLAGS="-I${TCLPRIVATE} -I${TCLPRIVATE}/generic -I${TCLBUILDDIR}"
 	CFLAGS="${ADDFLAGS} ${CFLAGS}"
 	CPPFLAGS="${ADDFLAGS} ${CPPFLAGS}"
 
 	unset TCLVERS
 	unset ADDFLAGS
+	unset TCLBUILDDIR
 	export TCLCONFIGDIR TCLPRIVATE CFLAGS CPPFLAGS
 fi
 
 # Determine platform
-PLATFORM="$(./platform)"
-export PLATFORM
+if [ -z "${FORCE_PLATFORM}" ]; then
+	PLATFORM="$(./platform)"
+	export PLATFORM
+else
+	PLATFORM="${FORCE_PLATFORM}"
+fi
 
 # Build all appropriate directories
 faileddirs=""
@@ -135,7 +172,6 @@ if [ -n "${faileddirs}" ]; then
 fi
 
 # Create tarfile of built packages
-PLATFORM="$(./platform)"
 DATECODE="$(date +%Y%m%d%H%M)"
 OUTFILEBASE="tclpkgs-${PLATFORM}-${DATECODE}"
 tar -cf - */out | bzip2 -9c > "${OUTFILEBASE}.tar.bz2"
