@@ -6,15 +6,20 @@ if [ ! -x "../platform" ]; then
 	exit 1
 fi
 
+if [ "${PLATFORM}" = "tcl" ]; then
+	rm -rf out
+
+	exit 0
+fi
+
 VERS=8.5.2
 SRC="src/tclDict-${VERS}.tar.gz"
 SRCURL="http://pascal.scheffers.net/software/tclDict-${VERS}.tar.gz"
 BUILDDIR="tclDict-${VERS}"
 WORKDIR="${TMPDIR:-/tmp}/dict-$$${RANDOM}${RANDOM}${RANDOM}"
-PLATFORM="$(../platform)"
 PLATDIR="$(pwd)/out/${PLATFORM}"
 
-export VERS SRC SRCURL BUILDDIR WORKDIR PLATFORM PLATDIR
+export VERS SRC SRCURL BUILDDIR WORKDIR PLATDIR
 
 if [ ! -f "${SRC}" ]; then
 	mkdir src >/dev/null 2>/dev/null
@@ -23,7 +28,7 @@ if [ ! -f "${SRC}" ]; then
 fi
 
 (
-	rm -rf build out
+	rm -rf build
 	mkdir -p "${PLATDIR}" >/dev/null 2>/dev/null
 	mkdir build
 
@@ -38,7 +43,7 @@ fi
 	cat configure.new > configure
 	rm -f configure.new
 
-	./configure --enable-shared --with-tcl="${TCLCONFIGDIR}" --prefix="${PLATDIR}" --libdir="${PLATDIR}" --bindir="${PLATDIR}"
+	bash ./configure --enable-shared --with-tcl="${TCLCONFIGDIR}" --prefix="${PLATDIR}" --libdir="${PLATDIR}" --bindir="${PLATDIR}" ${CONFIGUREEXTRA}
 
 	${MAKE:-make} || exit 1
 
